@@ -2,27 +2,26 @@ package Catmandu::Fix::format;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2012';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
+with 'Catmandu::Fix::Builder';
+
 has path => (fix_arg => 1);
 has spec => (fix_arg => 1);
 
-with 'Catmandu::Fix::SimpleGetValue';
-
-sub emit_value {
-    my ($self, $var, $fixer) = @_;
-    my $spec = $fixer->emit_string($self->spec);
-
-    "if (is_array_ref(${var})) {"
-        . "${var} = sprintf(${spec},\@{${var}});"
-        . "} elsif (is_hash_ref(${var})) {"
-        . "${var} = sprintf(${spec},\%{${var}});"
-        . "} elsif (is_string(${var})) {"
-        . "${var} = sprintf(${spec},${var});" . "}";
+sub _build_fixer {
+    my ($self) = @_;
+    my $spec = $self->spec;
+    as_path($self->path)->updater(
+        if_string    => sub {sprintf($spec, $_[0])},
+        if_array_ref => sub {sprintf($spec, @{$_[0]})},
+        if_hash_ref  => sub {sprintf($spec, %{$_[0]})},
+    );
 }
 
 1;
