@@ -2,24 +2,27 @@ package Catmandu::Fix::join_field;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2012';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
+use Catmandu::Util qw(is_value);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
-has path => (fix_arg => 1);
+has path      => (fix_arg => 1);
 has join_char => (fix_arg => 1, default => sub {''});
 
-with 'Catmandu::Fix::SimpleGetValue';
+with 'Catmandu::Fix::Builder';
 
-sub emit_value {
-    my ($self, $var, $fixer) = @_;
-    my $join_char = $fixer->emit_string($self->join_char);
-
-    "if (is_array_ref(${var})) {"
-        . "${var} = join(${join_char}, grep { is_value(\$_) } \@{${var}});"
-        . "}";
+sub _build_fixer {
+    my ($self) = @_;
+    my $join_char = $self->join_char;
+    as_path($self->path)->updater(
+        if_array_ref => sub {
+            join $join_char, grep {is_value($_)} @{$_[0]};
+        }
+    );
 }
 
 1;
