@@ -2,7 +2,7 @@ package Catmandu::Fix::sleep;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2012';
 
 use Moo;
 use Time::HiRes;
@@ -20,17 +20,17 @@ sub fix {
     my $sleep = $self->seconds;
     my $units = $self->units;
 
-    if ($units =~ /^MICROSECOND(S)?$/i) { }
-    elsif ($units =~ /^MILLISECOND(S)$/i) {
+    if ($units =~ /^microsecond(s)?$/i) { }
+    elsif ($units =~ /^millisecond(s)$/i) {
         $sleep *= 1000;
     }
-    elsif ($units =~ /^SECOND(S)?$/i) {
+    elsif ($units =~ /^second(s)?$/i) {
         $sleep *= 1000000;
     }
-    elsif ($units =~ /^MINUTE(S)?$/i) {
+    elsif ($units =~ /^minute(s)?$/i) {
         $sleep *= 60 * 1000000;
     }
-    elsif ($units =~ /^HOUR(S)?$/i) {
+    elsif ($units =~ /^hour(s)?$/i) {
         $sleep *= 3600 * 1000000;
     }
     else {
