@@ -2,22 +2,23 @@ package Catmandu::Fix::split_field;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2012';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
-has path => (fix_arg => 1);
+has path       => (fix_arg => 1);
 has split_char => (fix_arg => 1, default => sub {qr'\s+'});
 
-with 'Catmandu::Fix::SimpleGetValue';
+with 'Catmandu::Fix::Builder';
 
-sub emit_value {
-    my ($self, $var, $fixer) = @_;
-    my $split_char = $fixer->emit_string($self->split_char);
-
-    "${var} = [split ${split_char}, ${var}] if is_value(${var});";
+sub _build_fixer {
+    my ($self) = @_;
+    my $split_char = $self->split_char;
+    as_path($self->path)
+        ->updater(if_value => sub {[split $split_char, $_[0]]});
 }
 
 1;
