@@ -2,20 +2,16 @@ package Catmandu::IdGenerator::UUID;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.07';
+our $VERSION = '1.2012';
 
-use Data::UUID;
+use UUID::Tiny qw(:std);
 use Moo;
 use namespace::clean;
 
 with 'Catmandu::IdGenerator';
 
-has _uuid => (is => 'lazy', builder => '_build_uuid');
-
-sub _build_uuid {Data::UUID->new}
-
 sub generate {
-    $_[0]->_uuid->create_str;
+    create_uuid_as_string(UUID_V1);
 }
 
 1;
@@ -35,13 +31,14 @@ Catmandu::IdGenerator::UUID - Generator of UUID identifiers
     my $x = Catmandu::IdGenerator::UUID->new;
 
     for (1..100) {
-       printf "id: %s\n" m $x->generate;
+       printf "id: %s\n" , $x->generate;
     }
 
 =head1 DESCRIPTION
 
 This L<Catmandu::IdGenerator> generates identifiers based on the Universally
-Unique Identifier (UUID) standard. A UUID is a 128 bit number represented by
-lowercase hexadecimal digits such as C<de305d54-75b4-431b-adb2-eb6b9e546014>.
+Unique Identifier (UUID) v1 standard. A UUID string is a 128 bit number
+represented by lowercase hexadecimal digits such as
+C<de305d54-75b4-431b-adb2-eb6b9e546014>.
 
 =cut
