@@ -2,18 +2,18 @@ package Catmandu::Serializer::json;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.9505';
+our $VERSION = '1.2012';
 
-use JSON::XS ();
+use Cpanel::JSON::XS ();
 use Moo;
 use namespace::clean;
 
 sub serialize {
-    JSON::XS::encode_json($_[1]);
+    Cpanel::JSON::XS::encode_json($_[1]);
 }
 
 sub deserialize {
-    JSON::XS::decode_json($_[1]);
+    Cpanel::JSON::XS::decode_json($_[1]);
 }
 
 1;
