@@ -2,7 +2,7 @@ package Catmandu::Util;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.07';
+our $VERSION = '1.2012';
 
 use Exporter qw(import);
 use Sub::Quote    ();
@@ -114,7 +114,7 @@ sub TIESCALAR { }
 sub io {
     my ($arg, %opts) = @_;
     my $binmode = $opts{binmode} || $opts{encoding} || ':encoding(UTF-8)';
-    my $mode = $opts{mode} || 'r';
+    my $mode    = $opts{mode}    || 'r';
     my $io;
 
     if (is_scalar_ref($arg)) {
@@ -195,7 +195,9 @@ sub read_json {
 # Split a path on . or /, but not on \/ or \.
 sub split_path {
     my ($path) = @_;
-    return [map {s/\\(?=[\.\/])//g; $_} split /(?<!\\)[\.\/]/, trim($path)];
+    $path = trim($path);
+    $path =~ s/^\$[\.\/]//;
+    return [map {s/\\(?=[\.\/])//g; $_} split /(?<!\\)[\.\/]/, $path];
 }
 
 sub join_path {
@@ -215,7 +217,7 @@ sub normalize_path {    # taken from Dancer::FileUtils
 sub segmented_path {
     my ($id, %opts) = @_;
     my $segment_size = $opts{segment_size} || 3;
-    my $base_path = $opts{base_path};
+    my $base_path    = $opts{base_path};
     $id =~ s/[^0-9a-zA-Z]+//g;
     my @path = unpack "(A$segment_size)*", $id;
     defined $base_path
@@ -317,7 +319,7 @@ sub data_at {
         $path = split_path($path);
     }
     my $create = $opts{create};
-    my $_key = $opts{_key} // $opts{key};
+    my $_key   = $opts{_key} // $opts{key};
     if (defined $opts{key} && $create && @$path) {
         push @$path, $_key;
     }
@@ -331,8 +333,8 @@ sub data_at {
                     @$data;
             }
             else {
-                if    ($key eq '$first') {$key = 0}
-                elsif ($key eq '$last')  {$key = -1}
+                if    ($key eq '$first')   {$key                        = 0}
+                elsif ($key eq '$last')    {$key                        = -1}
                 elsif ($key eq '$prepend') {unshift @$data, undef; $key = 0}
                 elsif ($key eq '$append') {push @$data, undef; $key = @$data}
                 is_integer($key) || return;
@@ -413,8 +415,8 @@ sub array_rest {
 
 sub array_uniq {
     my ($arr) = @_;
-    my %seen = ();
-    my @vals = grep {not $seen{$_}++} @$arr;
+    my %seen  = ();
+    my @vals  = grep {not $seen{$_}++} @$arr;
     \@vals;
 }
 
@@ -467,6 +469,10 @@ sub is_bool {
         || $_[0]->isa('JSON::PP::Boolean'));
 }
 
+sub is_integer {
+    Data::Util::is_integer($_[0]) && $_[0] !~ /^0[0-9]/;
+}
+
 sub is_natural {
     is_integer($_[0]) && $_[0] >= 0;
 }
@@ -475,6 +481,12 @@ sub is_positive {
     is_integer($_[0]) && $_[0] >= 1;
 }
 
+sub is_float {
+    is_value($_[0])
+        && $_[0] =~ /^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$/
+        && $_[0] !~ /^0[0-9]/;
+}
+
 sub is_ref {
     ref $_[0] ? 1 : 0;
 }
@@ -482,7 +494,7 @@ sub is_ref {
 sub is_able {
     my $obj = shift;
     is_invocant($obj) || return 0;
-    $obj->can($_) || return 0 for @_;
+    $obj->can($_)     || return 0 for @_;
     1;
 }
 
@@ -502,7 +514,7 @@ sub check_maybe_able {
 sub is_instance {
     my $obj = shift;
     Scalar::Util::blessed($obj) || return 0;
-    $obj->isa($_) || return 0 for @_;
+    $obj->isa($_)               || return 0 for @_;
     1;
 }
 
@@ -533,13 +545,12 @@ Data::Util::install_subroutine(__PACKAGE__,
     is_value      => \&Data::Util::is_value,
     is_string     => \&Data::Util::is_string,
     is_number     => \&Data::Util::is_number,
-    is_integer    => \&Data::Util::is_integer,
 );
 
 for my $sym (
     qw(able instance invocant ref
     scalar_ref array_ref hash_ref code_ref regex_ref glob_ref
-    bool value string number integer natural positive)
+    bool value string number integer natural positive float)
     )
 {
     my $err_name = $sym;
@@ -641,7 +652,7 @@ sub use_lib {
 }
 
 sub pod_section {
-    my $class = is_ref($_[0]) ? ref(shift) : shift;
+    my $class   = is_ref($_[0]) ? ref(shift) : shift;
     my $section = uc(shift);
 
     unless (-r $class) {
@@ -651,7 +662,7 @@ sub pod_section {
     }
 
     my $text = "";
-    open my $input, "<", $class or return '';
+    open my $input,  "<", $class or return '';
     open my $output, ">", \$text;
 
     require Pod::Usage;    # lazy load only if needed
@@ -1089,6 +1100,12 @@ Equivalent to C<< is_integer($val) && $val >= 0 >>.
 Tests if C<$val> is a positive integer.
 Equivalent to C<< is_integer($val) && $val >= 1 >>.
 
+=item is_float($val)
+
+=item is_maybe_float($val)
+
+Tests if C<$val> is a floating point number.
+
 =item is_same($val, $other_val)
 
 Tests if C<$val> is deeply equal to C<$other_val>.
@@ -1177,6 +1194,10 @@ returning true or false they return their argument or die.
 
 =item check_maybe_positive($val)
 
+=item check_float($val)
+
+=item check_maybe_float($val)
+
 =item check_same($val, $other_val)
 
 =item check_different($val, $other_val)
